==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLookupswitch.h <==
// class soot.coffi.Instruction_Lookupswitch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 929b6430a0453af4 soot_coffi_Instruction__5fLookupswitch

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fLookupswitch_H_
#define _JC_soot_coffi_Instruction__5fLookupswitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_ByteCode$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_refs	_jc_soot_coffi_Instruction__5fLookupswitch$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs	_jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$refs	_jc_soot_coffi_Instruction__5fLookupswitch$refs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$nonrefs	_jc_soot_coffi_Instruction__5fLookupswitch$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$object	_jc_soot_coffi_Instruction__5fLookupswitch$object;

typedef const struct _jc_soot_coffi_Instruction__5fLookupswitch$vmethods	_jc_soot_coffi_Instruction__5fLookupswitch$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLookupswitch$vtable	_jc_soot_coffi_Instruction__5fLookupswitch$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLookupswitch$vtype	_jc_soot_coffi_Instruction__5fLookupswitch$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLookupswitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *);

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fLookupswitch$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_Instruction$object *);
extern jint _jc_soot_coffi_Instruction__5fLookupswitch$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5fLookupswitch$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, jint);
extern void _jc_soot_coffi_Instruction__5fLookupswitch$method$offsetToPointer$cf6c4bc72d76f691(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_ByteCode$object *);
extern jint _jc_soot_coffi_Instruction__5fLookupswitch$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fLookupswitch$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$branchpoints$0387b0529fae51a0;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$offsetToPointer$cf6c4bc72d76f691;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLookupswitch$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_Instruction$object *);
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, jint);
	void	(*offsetToPointer$cf6c4bc72d76f691)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_ByteCode$object *);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLookupswitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fLookupswitch$vmethods	soot_coffi_Instruction__5fLookupswitch;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLookupswitch$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLookupswitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_refs {
	_jc_int_array	*match__5foffsets;
	struct _jc_soot_coffi_Instruction$object	*default__5finst;
	_jc_object_array	*match__5finsts;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLookupswitch$refs {
    _jc_soot_coffi_Instruction__5fLookupswitch$sub_refs	soot_coffi_Instruction__5fLookupswitch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs {
	jbyte	pad;
	jint	default__5foffset;
	jint	npairs;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLookupswitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs	soot_coffi_Instruction__5fLookupswitch;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLookupswitch$object {
	_jc_soot_coffi_Instruction__5fLookupswitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLookupswitch$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLookupswitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLookupswitch$vtype _jc_soot_coffi_Instruction__5fLookupswitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLookupswitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLookupswitch$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLookupswitch_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLookupswitch.h <==
// class soot.coffi.Instruction_Lookupswitch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 929b6430a0453af4 soot_coffi_Instruction__5fLookupswitch

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fLookupswitch_H_
#define _JC_soot_coffi_Instruction__5fLookupswitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_ByteCode$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_refs	_jc_soot_coffi_Instruction__5fLookupswitch$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs	_jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$refs	_jc_soot_coffi_Instruction__5fLookupswitch$refs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$nonrefs	_jc_soot_coffi_Instruction__5fLookupswitch$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLookupswitch$object	_jc_soot_coffi_Instruction__5fLookupswitch$object;

typedef const struct _jc_soot_coffi_Instruction__5fLookupswitch$vmethods	_jc_soot_coffi_Instruction__5fLookupswitch$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLookupswitch$vtable	_jc_soot_coffi_Instruction__5fLookupswitch$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLookupswitch$vtype	_jc_soot_coffi_Instruction__5fLookupswitch$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLookupswitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fLookupswitch$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fLookupswitch$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fLookupswitch$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fLookupswitch$method$offsetToPointer$cf6c4bc72d76f691(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_ByteCode$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fLookupswitch$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fLookupswitch$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$branchpoints$0387b0529fae51a0;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$offsetToPointer$cf6c4bc72d76f691;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fLookupswitch$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLookupswitch$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, jint) _JC_JCNI_ATTR;
	void	(*offsetToPointer$cf6c4bc72d76f691)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_soot_coffi_ByteCode$object *) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fLookupswitch$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLookupswitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fLookupswitch$vmethods	soot_coffi_Instruction__5fLookupswitch;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLookupswitch$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLookupswitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_refs {
	_jc_int_array	*match__5foffsets;
	struct _jc_soot_coffi_Instruction$object	*default__5finst;
	_jc_object_array	*match__5finsts;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLookupswitch$refs {
    _jc_soot_coffi_Instruction__5fLookupswitch$sub_refs	soot_coffi_Instruction__5fLookupswitch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs {
	jbyte	pad;
	jint	default__5foffset;
	jint	npairs;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLookupswitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fLookupswitch$sub_nonrefs	soot_coffi_Instruction__5fLookupswitch;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLookupswitch$object {
	_jc_soot_coffi_Instruction__5fLookupswitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLookupswitch$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLookupswitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLookupswitch$vtype _jc_soot_coffi_Instruction__5fLookupswitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLookupswitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLookupswitch$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLookupswitch_H_ */
